
``selkie.xterm`` — XTerm control-sequence strings
=================================================

.. automodule:: selkie.xterm

.. autodata:: fg
.. autodata:: bg
.. autofunction:: black
.. autofunction:: red
.. autofunction:: green
.. autofunction:: yellow
.. autofunction:: blue
.. autofunction:: magenta
.. autofunction:: cyan
.. autofunction:: white
.. autofunction:: cursor_right
.. autofunction:: cursor_left
.. autofunction:: goto_column
